@@ -350,8 +350,11 @@ class MessageTypes(object):
         msg.ParseFromString(buf)
 
         if type_inst.decode_value == motorcortex_parameter_msg:
-            value_type = self.__types_by_hash[msg.info.data_type]
-            return ParameterMsg(msg.header, msg.info, value_type.decode(msg.value, msg.info.number_of_elements))
+            if msg.status == motorcortex.OK:
+                value_type = self.__types_by_hash[msg.info.data_type]
+                return ParameterMsg(msg.header, msg.info, value_type.decode(msg.value, msg.info.number_of_elements))
+            else:
+                return ParameterMsg(msg.header, msg.info, None)
         elif type_inst.decode_value == motorcortex_parameter_list_msg:
             params = []
             for param in msg.params:
