@@ -308,19 +308,9 @@ class Request(object):
         return get_param_msg
 
     @staticmethod
-    def parse(**kwargs):
-        conn_timeout_ms = 0
-        recv_timeout_ms = None
-        certificate = None
-        for key, value in kwargs.items():
-            if key == "recv_timeout_ms":
-                recv_timeout_ms = value
-            elif key == "conn_timeout_ms":
-                conn_timeout_ms = value
-            elif key == "timeout_ms":
-                conn_timeout_ms = value
-            elif key == 'certificate':
-                certificate = value
+    def parse(conn_timeout_ms=0, timeout_ms=None, recv_timeout_ms=None, certificate=None, login=None, password=None):
+        if timeout_ms and not conn_timeout_ms:
+            conn_timeout_ms = timeout_ms
 
         return conn_timeout_ms, recv_timeout_ms, certificate
 
