@@ -256,9 +256,15 @@ class Subscription(object):
     def _updateProtocol0(self, sub_msg, length):
         if sub_msg:
             counter = 0
+            n_params = len(self.__info.params)
             for param in self.__info.params:
                 offset = param.offset
                 size = param.size
+
+                # the last element in the group may have a variable size
+                if ((counter + 1) == n_params) and ((offset + size) > length):
+                    size = length - offset
+
                 if (offset + size) <= length:
                     timestamp = timespec._make(unpack_from('QQ', sub_msg, offset))
                     value = self.__decoder[counter].decode(sub_msg[offset + 16: offset + size],
@@ -276,9 +282,15 @@ class Subscription(object):
         if sub_msg:
             timestamp = timespec._make(unpack_from('QQ', sub_msg, 0))
             counter = 0
+            n_params = len(self.__info.params)
             for param in self.__info.params:
                 offset = param.offset + 16
                 size = param.size
+
+                # the last element in the group may have a variable size
+                if ((counter + 1) == n_params) and ((offset + size) > length):
+                    size = length - offset
+
                 if (offset + size) <= length:
                     value = self.__decoder[counter].decode(sub_msg[offset: offset + size],
                                                            param.info.number_of_elements)
